# -*- coding: utf-8 -*-

import string

import ldap.dn
import ldap.filter

from django.utils.encoding import force_text


class DnFormatter(string.Formatter):
    def get_value(self, key, args, kwargs):
        value = super(DnFormatter, self).get_value(key, args, kwargs)
        return value

    def get_field(self, field_name, args, kwargs):
        value, used_arg = super(DnFormatter, self).get_field(field_name, args, kwargs)
        if isinstance(value, (list, tuple)) and len(value) == 1:
            value = value[0]
        return value, used_arg

    def format_field(self, value, format_spec):
        value = super(DnFormatter, self).format_field(value, format_spec)
        return ldap.dn.escape_dn_chars(value)

    def convert_field(self, value, conversion):
        if conversion == 's':
            return force_text(value)
        return super(DnFormatter, self).convert_field(value, conversion)


class FilterFormatter(string.Formatter):
    def get_value(self, key, args, kwargs):
        value = super(FilterFormatter, self).get_value(key, args, kwargs)
        return value

    def get_field(self, field_name, args, kwargs):
        value, used_arg = super(FilterFormatter, self).get_field(field_name, args, kwargs)
        if isinstance(value, (list, tuple)) and len(value) == 1:
            value = value[0]
        return value, used_arg

    def format_field(self, value, format_spec):
        value = super(FilterFormatter, self).format_field(value, format_spec)
        return ldap.filter.escape_filter_chars(value)

    def convert_field(self, value, conversion):
        if conversion == 's':
            return force_text(value)
        return super(FilterFormatter, self).convert_field(value, conversion)
